@@ -63,7 +63,8 @@ def create_data_rows(lb_client:Client, base_client:baseClient, row:pandas.core.s
     Returns:
         Two items - the global_key, and a dictionary with "row_data", "global_key", "external_id" and "metadata_fields" keys
     """
-    row_data = str(row[row_data_col]) if not local_files else base_client.connector.upload_local_file(lb_client=lb_client, file_path=str(row[row_data_col]))
+    row_data_str = str(row[row_data_col])
+    row_data = base_client.connector.upload_local_file(lb_client=lb_client, file_path=row_data_str) if local_files else row_data_str
     metadata_fields = [{"schema_id" : metadata_name_key_to_schema['lb_integration_source'], "value" : "Pandas"}]
     if metadata_index:
         for metadata_field_name in metadata_index.keys():
